
#include <glib.h>
#include <glib-object.h>
#include <stdlib.h>
#include <string.h>
#include <stdio.h>
#include <gtk/gtk.h>
#include <glib/gi18n-lib.h>
#include <gio/gio.h>


#define TYPE_PROFILE (profile_get_type ())
#define PROFILE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PROFILE, Profile))
#define PROFILE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PROFILE, ProfileClass))
#define IS_PROFILE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PROFILE))
#define IS_PROFILE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PROFILE))
#define PROFILE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PROFILE, ProfileClass))

typedef struct _Profile Profile;
typedef struct _ProfileClass ProfileClass;
typedef struct _ProfilePrivate ProfilePrivate;

struct _Profile {
	GObject parent_instance;
	ProfilePrivate * priv;
	GKeyFile* keyFile;
};

struct _ProfileClass {
	GObjectClass parent_class;
};


static gpointer profile_parent_class = NULL;

GType profile_get_type (void);
enum  {
	PROFILE_DUMMY_PROPERTY
};
void profile_saveWindowSize (Profile* self, gint w, gint h);
void profile_saveWindowPanedPosition (Profile* self, gint pos);
gint profile_getWindowPanedPosition (Profile* self);
gint profile_getWindowWidth (Profile* self);
gint profile_getWindowHeight (Profile* self);
gboolean profile_load (Profile* self, const char* filename, GtkWindow* window);
void profile_toString (Profile* self);
void profile_save (Profile* self, const char* filename, GtkWindow* window);
Profile* profile_new (void);
Profile* profile_construct (GType object_type);
static GObject * profile_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
static void profile_finalize (GObject* obj);



void profile_saveWindowSize (Profile* self, gint w, gint h) {
	g_return_if_fail (self != NULL);
	if (w > 0) {
		g_key_file_set_integer (self->keyFile, "window", "width", w);
	}
	if (h > 0) {
		g_key_file_set_integer (self->keyFile, "window", "height", h);
	}
}


void profile_saveWindowPanedPosition (Profile* self, gint pos) {
	g_return_if_fail (self != NULL);
	g_key_file_set_integer (self->keyFile, "window", "paned_pos", pos);
}


gint profile_getWindowPanedPosition (Profile* self) {
	gint result;
	GError * _inner_error_;
	g_return_val_if_fail (self != NULL, 0);
	_inner_error_ = NULL;
	{
		gint _tmp0_;
		_tmp0_ = g_key_file_get_integer (self->keyFile, "window", "paned_pos", &_inner_error_);
		if (_inner_error_ != NULL) {
			if (_inner_error_->domain == G_KEY_FILE_ERROR) {
				goto __catch22_g_key_file_error;
			}
			goto __finally22;
		}
		result = _tmp0_;
		return result;
	}
	goto __finally22;
	__catch22_g_key_file_error:
	{
		GError * e;
		e = _inner_error_;
		_inner_error_ = NULL;
		{
			result = -1;
			(e == NULL) ? NULL : (e = (g_error_free (e), NULL));
			return result;
		}
	}
	__finally22:
	if (_inner_error_ != NULL) {
		g_critical ("file %s: line %d: uncaught error: %s", __FILE__, __LINE__, _inner_error_->message);
		g_clear_error (&_inner_error_);
		return 0;
	}
}


gint profile_getWindowWidth (Profile* self) {
	gint result;
	GError * _inner_error_;
	g_return_val_if_fail (self != NULL, 0);
	_inner_error_ = NULL;
	{
		gint _tmp0_;
		_tmp0_ = g_key_file_get_integer (self->keyFile, "window", "width", &_inner_error_);
		if (_inner_error_ != NULL) {
			if (_inner_error_->domain == G_KEY_FILE_ERROR) {
				goto __catch23_g_key_file_error;
			}
			goto __finally23;
		}
		result = _tmp0_;
		return result;
	}
	goto __finally23;
	__catch23_g_key_file_error:
	{
		GError * e;
		e = _inner_error_;
		_inner_error_ = NULL;
		{
			result = -1;
			(e == NULL) ? NULL : (e = (g_error_free (e), NULL));
			return result;
		}
	}
	__finally23:
	if (_inner_error_ != NULL) {
		g_critical ("file %s: line %d: uncaught error: %s", __FILE__, __LINE__, _inner_error_->message);
		g_clear_error (&_inner_error_);
		return 0;
	}
}


gint profile_getWindowHeight (Profile* self) {
	gint result;
	GError * _inner_error_;
	g_return_val_if_fail (self != NULL, 0);
	_inner_error_ = NULL;
	{
		gint _tmp0_;
		_tmp0_ = g_key_file_get_integer (self->keyFile, "window", "height", &_inner_error_);
		if (_inner_error_ != NULL) {
			if (_inner_error_->domain == G_KEY_FILE_ERROR) {
				goto __catch24_g_key_file_error;
			}
			goto __finally24;
		}
		result = _tmp0_;
		return result;
	}
	goto __finally24;
	__catch24_g_key_file_error:
	{
		GError * e;
		e = _inner_error_;
		_inner_error_ = NULL;
		{
			result = -1;
			(e == NULL) ? NULL : (e = (g_error_free (e), NULL));
			return result;
		}
	}
	__finally24:
	if (_inner_error_ != NULL) {
		g_critical ("file %s: line %d: uncaught error: %s", __FILE__, __LINE__, _inner_error_->message);
		g_clear_error (&_inner_error_);
		return 0;
	}
}


gboolean profile_load (Profile* self, const char* filename, GtkWindow* window) {
	gboolean result;
	GError * _inner_error_;
	char* f;
	gboolean default_profile;
	g_return_val_if_fail (self != NULL, FALSE);
	g_return_val_if_fail (window != NULL, FALSE);
	_inner_error_ = NULL;
	f = NULL;
	default_profile = FALSE;
	if (filename == NULL) {
		char* _tmp0_;
		default_profile = TRUE;
		_tmp0_ = NULL;
		f = (_tmp0_ = g_strdup_printf ("%s/moserial.conf", g_get_user_config_dir ()), f = (g_free (f), NULL), _tmp0_);
	} else {
		char* _tmp2_;
		const char* _tmp1_;
		_tmp2_ = NULL;
		_tmp1_ = NULL;
		f = (_tmp2_ = (_tmp1_ = filename, (_tmp1_ == NULL) ? NULL : g_strdup (_tmp1_)), f = (g_free (f), NULL), _tmp2_);
	}
	{
		g_key_file_load_from_file (self->keyFile, f, G_KEY_FILE_NONE, &_inner_error_);
		if (_inner_error_ != NULL) {
			if (_inner_error_->domain == G_KEY_FILE_ERROR) {
				goto __catch25_g_key_file_error;
			}
			if (_inner_error_->domain == G_FILE_ERROR) {
				goto __catch25_g_file_error;
			}
			goto __finally25;
		}
		result = TRUE;
		f = (g_free (f), NULL);
		return result;
	}
	goto __finally25;
	__catch25_g_key_file_error:
	{
		GError * e;
		e = _inner_error_;
		_inner_error_ = NULL;
		{
			fprintf (stdout, "%s\n", e->message);
			/* try loading the non-broken parts of the profile - return true */
			result = TRUE;
			(e == NULL) ? NULL : (e = (g_error_free (e), NULL));
			f = (g_free (f), NULL);
			return result;
		}
	}
	goto __finally25;
	__catch25_g_file_error:
	{
		GError * e;
		e = _inner_error_;
		_inner_error_ = NULL;
		{
			if (!default_profile) {
				char* _tmp3_;
				GtkMessageDialog* _tmp4_;
				GtkMessageDialog* errorDialog;
				_tmp3_ = NULL;
				_tmp4_ = NULL;
				errorDialog = (_tmp4_ = g_object_ref_sink ((GtkMessageDialog*) gtk_message_dialog_new (window, GTK_DIALOG_DESTROY_WITH_PARENT, GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE, _tmp3_ = g_strdup_printf ("%s: %s\n%s", _ ("Error: Could not open file"), filename, e->message), NULL)), _tmp3_ = (g_free (_tmp3_), NULL), _tmp4_);
				gtk_dialog_run ((GtkDialog*) errorDialog);
				gtk_object_destroy ((GtkObject*) errorDialog);
				(errorDialog == NULL) ? NULL : (errorDialog = (g_object_unref (errorDialog), NULL));
			}
			result = FALSE;
			(e == NULL) ? NULL : (e = (g_error_free (e), NULL));
			f = (g_free (f), NULL);
			return result;
		}
	}
	__finally25:
	if (_inner_error_ != NULL) {
		f = (g_free (f), NULL);
		g_critical ("file %s: line %d: uncaught error: %s", __FILE__, __LINE__, _inner_error_->message);
		g_clear_error (&_inner_error_);
		return FALSE;
	}
	f = (g_free (f), NULL);
}


void profile_toString (Profile* self) {
	gsize s;
	char* _tmp0_;
	g_return_if_fail (self != NULL);
	s = 0UL;
	_tmp0_ = NULL;
	fprintf (stdout, "%s\n", _tmp0_ = g_key_file_to_data (self->keyFile, &s, NULL));
	_tmp0_ = (g_free (_tmp0_), NULL);
}


void profile_save (Profile* self, const char* filename, GtkWindow* window) {
	GError * _inner_error_;
	GFile* file;
	GFileOutputStream* fos;
	char* f;
	gboolean default_profile;
	GFile* _tmp3_;
	g_return_if_fail (self != NULL);
	g_return_if_fail (window != NULL);
	_inner_error_ = NULL;
	file = NULL;
	fos = NULL;
	f = NULL;
	default_profile = FALSE;
	if (filename == NULL) {
		char* _tmp0_;
		default_profile = TRUE;
		_tmp0_ = NULL;
		f = (_tmp0_ = g_strdup_printf ("%s/moserial.conf", g_get_user_config_dir ()), f = (g_free (f), NULL), _tmp0_);
	} else {
		char* _tmp2_;
		const char* _tmp1_;
		_tmp2_ = NULL;
		_tmp1_ = NULL;
		f = (_tmp2_ = (_tmp1_ = filename, (_tmp1_ == NULL) ? NULL : g_strdup (_tmp1_)), f = (g_free (f), NULL), _tmp2_);
	}
	_tmp3_ = NULL;
	file = (_tmp3_ = g_file_new_for_path (f), (file == NULL) ? NULL : (file = (g_object_unref (file), NULL)), _tmp3_);
	{
		gsize s;
		char* data;
		GFileOutputStream* _tmp4_;
		GFileOutputStream* _tmp5_;
		char* _tmp6_;
		s = 0UL;
		data = NULL;
		_tmp4_ = g_file_replace (file, NULL, FALSE, G_FILE_CREATE_NONE, NULL, &_inner_error_);
		if (_inner_error_ != NULL) {
			data = (g_free (data), NULL);
			goto __catch26_g_error;
			goto __finally26;
		}
		_tmp5_ = NULL;
		fos = (_tmp5_ = _tmp4_, (fos == NULL) ? NULL : (fos = (g_object_unref (fos), NULL)), _tmp5_);
		_tmp6_ = NULL;
		data = (_tmp6_ = g_key_file_to_data (self->keyFile, &s, NULL), data = (g_free (data), NULL), _tmp6_);
		g_output_stream_write ((GOutputStream*) fos, data, s, NULL, &_inner_error_);
		if (_inner_error_ != NULL) {
			data = (g_free (data), NULL);
			goto __catch26_g_error;
			goto __finally26;
		}
		data = (g_free (data), NULL);
	}
	goto __finally26;
	__catch26_g_error:
	{
		GError * e;
		e = _inner_error_;
		_inner_error_ = NULL;
		{
			fprintf (stdout, "profile.save error: %s\n", e->message);
			if (!default_profile) {
				char* _tmp7_;
				GtkMessageDialog* _tmp8_;
				GtkMessageDialog* errorDialog;
				_tmp7_ = NULL;
				_tmp8_ = NULL;
				errorDialog = (_tmp8_ = g_object_ref_sink ((GtkMessageDialog*) gtk_message_dialog_new (window, GTK_DIALOG_DESTROY_WITH_PARENT, GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE, _tmp7_ = g_strdup_printf ("%s: %s\n%s", _ ("Error: Could not open file"), filename, e->message), NULL)), _tmp7_ = (g_free (_tmp7_), NULL), _tmp8_);
				gtk_dialog_run ((GtkDialog*) errorDialog);
				gtk_object_destroy ((GtkObject*) errorDialog);
				(errorDialog == NULL) ? NULL : (errorDialog = (g_object_unref (errorDialog), NULL));
			}
			(e == NULL) ? NULL : (e = (g_error_free (e), NULL));
		}
	}
	__finally26:
	if (_inner_error_ != NULL) {
		(file == NULL) ? NULL : (file = (g_object_unref (file), NULL));
		(fos == NULL) ? NULL : (fos = (g_object_unref (fos), NULL));
		f = (g_free (f), NULL);
		g_critical ("file %s: line %d: uncaught error: %s", __FILE__, __LINE__, _inner_error_->message);
		g_clear_error (&_inner_error_);
		return;
	}
	(file == NULL) ? NULL : (file = (g_object_unref (file), NULL));
	(fos == NULL) ? NULL : (fos = (g_object_unref (fos), NULL));
	f = (g_free (f), NULL);
}


Profile* profile_construct (GType object_type) {
	Profile * self;
	self = g_object_newv (object_type, 0, NULL);
	return self;
}


Profile* profile_new (void) {
	return profile_construct (TYPE_PROFILE);
}


static GObject * profile_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	ProfileClass * klass;
	GObjectClass * parent_class;
	Profile * self;
	klass = PROFILE_CLASS (g_type_class_peek (TYPE_PROFILE));
	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
	self = PROFILE (obj);
	{
		GKeyFile* _tmp0_;
		_tmp0_ = NULL;
		self->keyFile = (_tmp0_ = g_key_file_new (), (self->keyFile == NULL) ? NULL : (self->keyFile = (g_key_file_free (self->keyFile), NULL)), _tmp0_);
	}
	return obj;
}


static void profile_class_init (ProfileClass * klass) {
	profile_parent_class = g_type_class_peek_parent (klass);
	G_OBJECT_CLASS (klass)->constructor = profile_constructor;
	G_OBJECT_CLASS (klass)->finalize = profile_finalize;
}


static void profile_instance_init (Profile * self) {
}


static void profile_finalize (GObject* obj) {
	Profile * self;
	self = PROFILE (obj);
	(self->keyFile == NULL) ? NULL : (self->keyFile = (g_key_file_free (self->keyFile), NULL));
	G_OBJECT_CLASS (profile_parent_class)->finalize (obj);
}


GType profile_get_type (void) {
	static GType profile_type_id = 0;
	if (profile_type_id == 0) {
		static const GTypeInfo g_define_type_info = { sizeof (ProfileClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) profile_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (Profile), 0, (GInstanceInitFunc) profile_instance_init, NULL };
		profile_type_id = g_type_register_static (G_TYPE_OBJECT, "Profile", &g_define_type_info, 0);
	}
	return profile_type_id;
}




